#!/usr/bin/env bash
set -euo pipefail

# Linux-compatible launcher alias.
# Kept for backward compatibility with earlier evaluator package references.

SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
exec "$SCRIPT_DIR/gal2-daemon-linux.sh"
